"""Advanced research tools: literature review, similarity, gaps, methodology, citations."""

from hivemind.tools.research_advanced.literature_review_generator import LiteratureReviewGeneratorTool
from hivemind.tools.research_advanced.paper_similarity_search import PaperSimilaritySearchTool
from hivemind.tools.research_advanced.research_gap_finder import ResearchGapFinderTool
from hivemind.tools.research_advanced.methodology_extractor import MethodologyExtractorTool
from hivemind.tools.research_advanced.paper_contribution_extractor import PaperContributionExtractorTool
from hivemind.tools.research_advanced.paper_dataset_identifier import PaperDatasetIdentifierTool
from hivemind.tools.research_advanced.citation_context_extractor import CitationContextExtractorTool
from hivemind.tools.research_advanced.research_topic_mapper import ResearchTopicMapperTool
from hivemind.tools.research_advanced.paper_trend_analyzer import PaperTrendAnalyzerTool
from hivemind.tools.research_advanced.paper_method_comparator import PaperMethodComparatorTool
from hivemind.tools.research_advanced.parallel_document_analyzer import ParallelDocumentAnalyzerTool
from hivemind.tools.research_advanced.swarm_literature_review import SwarmLiteratureReviewTool
